#  type: ignore
import uuid
from typing import Callable, Iterable, List, Optional, Tuple, Union

import grpc
from grpc.aio._call import StreamStreamCall
from grpc.aio._interceptor import ClientCallDetails
from grpc.aio._typing import RequestIterableType, RequestType, ResponseType

from .auth import ClientAuthentication

_RequestMetadata = Optional[Iterable[Tuple[str, str]]]
ResponseIterableType = grpc.aio._typing.ResponseIterableType


def get_auth_client_interceptors(
    authentication: ClientAuthentication,
) -> List[grpc.aio.ClientInterceptor]:
    return [
        _AuthInterceptorUnaryUnary(authentication),
        _AuthInterceptorUnaryStream(authentication),
        _AuthInterceptorStreamUnary(authentication),
        _AuthInterceptorStreamStream(authentication),
    ]


def get_request_id_interceptors(
    request_id: uuid.UUID,
) -> List[grpc.aio.ClientInterceptor]:
    return [
        _RequestIdInterceptorUnaryUnary(request_id),
        _RequestIdInterceptorUnaryStream(request_id),
        _RequestIdInterceptorStreamUnary(request_id),
        _RequestIdInterceptorStreamStream(request_id),
    ]


class _AuthInterceptorAgent:
    def __init__(self, authentication: ClientAuthentication):
        self.__authentication = authentication

    def _add_auth(self, details: grpc.aio.ClientCallDetails) -> grpc.aio.ClientCallDetails:
        return grpc.aio.ClientCallDetails(
            method=details.method,
            timeout=details.timeout,
            metadata=self.__add_auth_meta(details.metadata),
            credentials=details.credentials,
            wait_for_ready=None,
        )

    def __add_auth_meta(self, metadata: _RequestMetadata = None) -> _RequestMetadata:
        result: Tuple[Tuple[str, str]] = []
        if metadata is not None:
            for m in metadata:
                result.append(m)
        result.append(
            (
                self.__authentication.get_authentication_header_key(),
                self.__authentication.create_authentication_header_value(),
            )
        )
        return tuple(result)


class _AuthInterceptorUnaryUnary(_AuthInterceptorAgent, grpc.aio.UnaryUnaryClientInterceptor):
    async def intercept_unary_unary(
        self,
        continuation: Callable[[grpc.aio.ClientCallDetails, RequestType], grpc.aio.UnaryUnaryCall],
        client_call_details: grpc.aio.ClientCallDetails,
        request: RequestType,
    ) -> Union[grpc.aio._call.UnaryUnaryCall, ResponseType]:
        res = await continuation(self._add_auth(client_call_details), request)
        return res


class _AuthInterceptorUnaryStream(_AuthInterceptorAgent, grpc.aio.UnaryStreamClientInterceptor):
    async def intercept_unary_stream(
        self,
        continuation: Callable[[grpc.aio.ClientCallDetails, RequestType], grpc.aio.UnaryStreamCall],
        details: grpc.aio.ClientCallDetails,
        request: RequestType,
    ) -> Union[ResponseIterableType, grpc.aio.UnaryStreamCall]:
        return await continuation(self._add_auth(details), request)


class _AuthInterceptorStreamUnary(
    _AuthInterceptorAgent,
    grpc.aio.StreamUnaryClientInterceptor,
):
    async def intercept_stream_unary(
        self,
        continuation: Callable[[grpc.aio.ClientCallDetails, RequestType], grpc.aio.StreamUnaryCall],
        client_call_details: grpc.aio.ClientCallDetails,
        request_iterator: RequestIterableType,
    ) -> grpc.aio.StreamUnaryCall:
        return await continuation(self._add_auth(client_call_details), request_iterator)


class _AuthInterceptorStreamStream(
    _AuthInterceptorAgent,
    grpc.aio.StreamStreamClientInterceptor,
):
    async def intercept_stream_stream(
        self,
        continuation: Callable[[ClientCallDetails, RequestType], StreamStreamCall],
        client_call_details: ClientCallDetails,
        request_iterator: RequestIterableType,
    ) -> Union[ResponseIterableType, StreamStreamCall]:
        return await continuation(self._add_auth(client_call_details), request_iterator)


class _RequestIdInterceptorAgent:
    _interceptor_type: str

    def __init__(self, request_id: uuid.UUID):
        self.__request_id = request_id
        self.__counter = 0

    def _add_request_id(self, details: ClientCallDetails) -> ClientCallDetails:
        self.__counter += 1

        metadata = ()
        if details.metadata is not None:
            metadata = tuple(details.metadata)
        metadata += (
            (
                "x-request-id",
                f"{self.__request_id}/{self._interceptor_type}_{self.__counter}",
            ),
        )

        res = grpc.aio.ClientCallDetails(
            method=details.method,
            timeout=details.timeout,
            metadata=metadata,
            credentials=details.credentials,
            wait_for_ready=None,
        )
        return res


class _RequestIdInterceptorUnaryUnary(
    _RequestIdInterceptorAgent,
    grpc.aio.UnaryUnaryClientInterceptor,
):
    _interceptor_type = "unary_unary"

    async def intercept_unary_unary(
        self,
        continuation: Callable[[grpc.aio.ClientCallDetails, RequestType], grpc.aio.UnaryUnaryCall],
        client_call_details: grpc.aio.ClientCallDetails,
        request: RequestType,
    ) -> Union[grpc.aio.UnaryUnaryCall, ResponseType]:
        return await continuation(self._add_request_id(client_call_details), request)


class _RequestIdInterceptorUnaryStream(
    _RequestIdInterceptorAgent,
    grpc.aio.UnaryStreamClientInterceptor,
):
    _interceptor_type = "unary_stream"

    async def intercept_unary_stream(
        self,
        continuation: Callable[[grpc.aio.ClientCallDetails, RequestType], grpc.aio.UnaryStreamCall],
        client_call_details: grpc.aio.ClientCallDetails,
        request: RequestType,
    ) -> Union[ResponseIterableType, grpc.aio.UnaryStreamCall]:
        return await continuation(self._add_request_id(client_call_details), request)


class _RequestIdInterceptorStreamUnary(
    _RequestIdInterceptorAgent,
    grpc.aio.StreamUnaryClientInterceptor,
):
    _interceptor_type = "stream_unary"

    async def intercept_stream_unary(
        self,
        continuation: Callable[[grpc.aio.ClientCallDetails, RequestType], grpc.aio.StreamUnaryCall],
        client_call_details: grpc.aio.ClientCallDetails,
        request_iterator: RequestIterableType,
    ) -> grpc.aio.StreamUnaryCall:
        return await continuation(self._add_request_id(client_call_details), request_iterator)


class _RequestIdInterceptorStreamStream(_RequestIdInterceptorAgent, grpc.aio.StreamStreamClientInterceptor):
    _interceptor_type = "stream_stream"

    async def intercept_stream_stream(
        self,
        continuation: Callable[[ClientCallDetails, RequestType], StreamStreamCall],
        client_call_details: ClientCallDetails,
        request_iterator: RequestIterableType,
    ) -> Union[ResponseIterableType, StreamStreamCall]:
        return await continuation(self._add_request_id(client_call_details), request_iterator)



from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TraceOperation(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    Operation_notset: _ClassVar[TraceOperation]
    Operation_unknown: _ClassVar[TraceOperation]
    Operation_write: _ClassVar[TraceOperation]
    Operation_read: _ClassVar[TraceOperation]

class DeviceResultStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    Device_notset: _ClassVar[DeviceResultStatus]
    Device_ok: _ClassVar[DeviceResultStatus]
    Device_error: _ClassVar[DeviceResultStatus]

class FileStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    FileStatus_notset: _ClassVar[FileStatus]
    FileStatus_ok: _ClassVar[FileStatus]
    FileStatus_error: _ClassVar[FileStatus]
    FileStatus_not_found: _ClassVar[FileStatus]
    FileStatus_is_dir: _ClassVar[FileStatus]
Operation_notset: TraceOperation
Operation_unknown: TraceOperation
Operation_write: TraceOperation
Operation_read: TraceOperation
Device_notset: DeviceResultStatus
Device_ok: DeviceResultStatus
Device_error: DeviceResultStatus
FileStatus_notset: FileStatus
FileStatus_ok: FileStatus
FileStatus_error: FileStatus
FileStatus_not_found: FileStatus
FileStatus_is_dir: FileStatus

class QA(_message.Message):
    __slots__ = ("question", "answer")
    QUESTION_FIELD_NUMBER: _ClassVar[int]
    ANSWER_FIELD_NUMBER: _ClassVar[int]
    question: str
    answer: str
    def __init__(self, question: _Optional[str] = ..., answer: _Optional[str] = ...) -> None: ...

class Credentials(_message.Message):
    __slots__ = ("login", "password")
    LOGIN_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    login: str
    password: str
    def __init__(self, login: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class CMD(_message.Message):
    __slots__ = ("host", "cmd", "trace", "qa", "read_timeout", "cmd_timeout", "string_result", "host_params")
    HOST_FIELD_NUMBER: _ClassVar[int]
    CMD_FIELD_NUMBER: _ClassVar[int]
    TRACE_FIELD_NUMBER: _ClassVar[int]
    QA_FIELD_NUMBER: _ClassVar[int]
    READ_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    CMD_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    STRING_RESULT_FIELD_NUMBER: _ClassVar[int]
    HOST_PARAMS_FIELD_NUMBER: _ClassVar[int]
    host: str
    cmd: str
    trace: bool
    qa: _containers.RepeatedCompositeFieldContainer[QA]
    read_timeout: float
    cmd_timeout: float
    string_result: bool
    host_params: HostParams
    def __init__(self, host: _Optional[str] = ..., cmd: _Optional[str] = ..., trace: bool = ..., qa: _Optional[_Iterable[_Union[QA, _Mapping]]] = ..., read_timeout: _Optional[float] = ..., cmd_timeout: _Optional[float] = ..., string_result: bool = ..., host_params: _Optional[_Union[HostParams, _Mapping]] = ...) -> None: ...

class Device(_message.Message):
    __slots__ = ("name", "prompt_expression", "error_expression", "pager_expression")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROMPT_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    ERROR_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    PAGER_EXPRESSION_FIELD_NUMBER: _ClassVar[int]
    name: str
    prompt_expression: str
    error_expression: str
    pager_expression: str
    def __init__(self, name: _Optional[str] = ..., prompt_expression: _Optional[str] = ..., error_expression: _Optional[str] = ..., pager_expression: _Optional[str] = ...) -> None: ...

class CMDNetconf(_message.Message):
    __slots__ = ("host", "cmd", "json", "read_timeout", "cmd_timeout")
    HOST_FIELD_NUMBER: _ClassVar[int]
    CMD_FIELD_NUMBER: _ClassVar[int]
    JSON_FIELD_NUMBER: _ClassVar[int]
    READ_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    CMD_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    host: str
    cmd: str
    json: bool
    read_timeout: float
    cmd_timeout: float
    def __init__(self, host: _Optional[str] = ..., cmd: _Optional[str] = ..., json: bool = ..., read_timeout: _Optional[float] = ..., cmd_timeout: _Optional[float] = ...) -> None: ...

class CMDTraceItem(_message.Message):
    __slots__ = ("operation", "data")
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    operation: TraceOperation
    data: bytes
    def __init__(self, operation: _Optional[_Union[TraceOperation, str]] = ..., data: _Optional[bytes] = ...) -> None: ...

class HostParams(_message.Message):
    __slots__ = ("host", "credentials", "port", "device", "ip")
    HOST_FIELD_NUMBER: _ClassVar[int]
    CREDENTIALS_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    IP_FIELD_NUMBER: _ClassVar[int]
    host: str
    credentials: Credentials
    port: int
    device: str
    ip: str
    def __init__(self, host: _Optional[str] = ..., credentials: _Optional[_Union[Credentials, _Mapping]] = ..., port: _Optional[int] = ..., device: _Optional[str] = ..., ip: _Optional[str] = ...) -> None: ...

class CMDResult(_message.Message):
    __slots__ = ("out", "out_str", "error", "error_str", "trace", "status")
    OUT_FIELD_NUMBER: _ClassVar[int]
    OUT_STR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_STR_FIELD_NUMBER: _ClassVar[int]
    TRACE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    out: bytes
    out_str: str
    error: bytes
    error_str: str
    trace: _containers.RepeatedCompositeFieldContainer[CMDTraceItem]
    status: int
    def __init__(self, out: _Optional[bytes] = ..., out_str: _Optional[str] = ..., error: _Optional[bytes] = ..., error_str: _Optional[str] = ..., trace: _Optional[_Iterable[_Union[CMDTraceItem, _Mapping]]] = ..., status: _Optional[int] = ...) -> None: ...

class DeviceResult(_message.Message):
    __slots__ = ("res", "error")
    RES_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    res: DeviceResultStatus
    error: str
    def __init__(self, res: _Optional[_Union[DeviceResultStatus, str]] = ..., error: _Optional[str] = ...) -> None: ...

class FileDownloadRequest(_message.Message):
    __slots__ = ("host", "paths", "device", "host_params")
    HOST_FIELD_NUMBER: _ClassVar[int]
    PATHS_FIELD_NUMBER: _ClassVar[int]
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    HOST_PARAMS_FIELD_NUMBER: _ClassVar[int]
    host: str
    paths: _containers.RepeatedScalarFieldContainer[str]
    device: str
    host_params: HostParams
    def __init__(self, host: _Optional[str] = ..., paths: _Optional[_Iterable[str]] = ..., device: _Optional[str] = ..., host_params: _Optional[_Union[HostParams, _Mapping]] = ...) -> None: ...

class FileData(_message.Message):
    __slots__ = ("path", "data", "status")
    PATH_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    path: str
    data: bytes
    status: FileStatus
    def __init__(self, path: _Optional[str] = ..., data: _Optional[bytes] = ..., status: _Optional[_Union[FileStatus, str]] = ...) -> None: ...

class FileUploadRequest(_message.Message):
    __slots__ = ("host", "device", "files", "host_params")
    HOST_FIELD_NUMBER: _ClassVar[int]
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    FILES_FIELD_NUMBER: _ClassVar[int]
    HOST_PARAMS_FIELD_NUMBER: _ClassVar[int]
    host: str
    device: str
    files: _containers.RepeatedCompositeFieldContainer[FileData]
    host_params: HostParams
    def __init__(self, host: _Optional[str] = ..., device: _Optional[str] = ..., files: _Optional[_Iterable[_Union[FileData, _Mapping]]] = ..., host_params: _Optional[_Union[HostParams, _Mapping]] = ...) -> None: ...

class FilesResult(_message.Message):
    __slots__ = ("files",)
    FILES_FIELD_NUMBER: _ClassVar[int]
    files: _containers.RepeatedCompositeFieldContainer[FileData]
    def __init__(self, files: _Optional[_Iterable[_Union[FileData, _Mapping]]] = ...) -> None: ...



import abc


class ClientAuthentication(abc.ABC):
    @abc.abstractmethod
    def get_authentication_header_key(self) -> str:
        """
        Name of the header used for authentication.
        :return: Header name.
        """
        raise NotImplementedError("abstract method get_authentication_header_key() not implemented")

    @abc.abstractmethod
    def create_authentication_header_value(self) -> str:
        """
        Creates value for authentication header.
        :return: Authentication header value.
        """
        raise NotImplementedError("abstract method create_authentication_header_value() not implemented")


class OAuthClientAuthentication(ClientAuthentication):
    def __init__(self, token: str):
        self.__token = token

    def get_authentication_header_key(self) -> str:
        return "authorization"

    def create_authentication_header_value(self) -> str:
        return f"OAuth {self.__token}"


class BasicClientAuthentication(ClientAuthentication):
    def __init__(self, token: str):
        self.__token = token

    def get_authentication_header_key(self) -> str:
        return "authorization"

    def create_authentication_header_value(self) -> str:
        return f"Basic {self.__token}"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: server.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cserver.proto\x12\x07gnetcli\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"&\n\x02QA\x12\x10\n\x08question\x18\x01 \x01(\t\x12\x0e\n\x06\x61nswer\x18\x02 \x01(\t\".\n\x0b\x43redentials\x12\r\n\x05login\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\xb4\x01\n\x03\x43MD\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x01(\t\x12\r\n\x05trace\x18\x03 \x01(\x08\x12\x17\n\x02qa\x18\x04 \x03(\x0b\x32\x0b.gnetcli.QA\x12\x14\n\x0cread_timeout\x18\x05 \x01(\x01\x12\x13\n\x0b\x63md_timeout\x18\x06 \x01(\x01\x12\x15\n\rstring_result\x18\x08 \x01(\x08\x12(\n\x0bhost_params\x18\t \x01(\x0b\x32\x13.gnetcli.HostParams\"e\n\x06\x44\x65vice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11prompt_expression\x18\x02 \x01(\t\x12\x18\n\x10\x65rror_expression\x18\x03 \x01(\t\x12\x18\n\x10pager_expression\x18\x04 \x01(\t\"`\n\nCMDNetconf\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0b\n\x03\x63md\x18\x02 \x01(\t\x12\x0c\n\x04json\x18\x03 \x01(\x08\x12\x14\n\x0cread_timeout\x18\x04 \x01(\x01\x12\x13\n\x0b\x63md_timeout\x18\x05 \x01(\x01\"H\n\x0c\x43MDTraceItem\x12*\n\toperation\x18\x01 \x01(\x0e\x32\x17.gnetcli.TraceOperation\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"o\n\nHostParams\x12\x0c\n\x04host\x18\x01 \x01(\t\x12)\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x14.gnetcli.Credentials\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x04 \x01(\t\x12\n\n\x02ip\x18\x05 \x01(\t\"\x81\x01\n\tCMDResult\x12\x0b\n\x03out\x18\x01 \x01(\x0c\x12\x0f\n\x07out_str\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\x0c\x12\x11\n\terror_str\x18\x04 \x01(\t\x12$\n\x05trace\x18\x05 \x03(\x0b\x32\x15.gnetcli.CMDTraceItem\x12\x0e\n\x06status\x18\x06 \x01(\x05\"G\n\x0c\x44\x65viceResult\x12(\n\x03res\x18\x01 \x01(\x0e\x32\x1b.gnetcli.DeviceResultStatus\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"l\n\x13\x46ileDownloadRequest\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\x12\x0e\n\x06\x64\x65vice\x18\x03 \x01(\t\x12(\n\x0bhost_params\x18\x05 \x01(\x0b\x32\x13.gnetcli.HostParams\"K\n\x08\x46ileData\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12#\n\x06status\x18\x03 \x01(\x0e\x32\x13.gnetcli.FileStatus\"}\n\x11\x46ileUploadRequest\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x04 \x01(\t\x12 \n\x05\x66iles\x18\x03 \x03(\x0b\x32\x11.gnetcli.FileData\x12(\n\x0bhost_params\x18\x06 \x01(\x0b\x32\x13.gnetcli.HostParams\"/\n\x0b\x46ilesResult\x12 \n\x05\x66iles\x18\x01 \x03(\x0b\x32\x11.gnetcli.FileData*f\n\x0eTraceOperation\x12\x14\n\x10Operation_notset\x10\x00\x12\x15\n\x11Operation_unknown\x10\x01\x12\x13\n\x0fOperation_write\x10\x02\x12\x12\n\x0eOperation_read\x10\x03*H\n\x12\x44\x65viceResultStatus\x12\x11\n\rDevice_notset\x10\x00\x12\r\n\tDevice_ok\x10\x01\x12\x10\n\x0c\x44\x65vice_error\x10\x02*}\n\nFileStatus\x12\x15\n\x11\x46ileStatus_notset\x10\x00\x12\x11\n\rFileStatus_ok\x10\x01\x12\x14\n\x10\x46ileStatus_error\x10\x02\x12\x18\n\x14\x46ileStatus_not_found\x10\x03\x12\x15\n\x11\x46ileStatus_is_dir\x10\x04\x32\x8c\x05\n\x07Gnetcli\x12\x64\n\x0fSetupHostParams\x12\x13.gnetcli.HostParams\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/api/v1/setup_host_params:\x01*\x12\x41\n\x04\x45xec\x12\x0c.gnetcli.CMD\x1a\x12.gnetcli.CMDResult\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/api/v1/exec:\x01*\x12\x32\n\x08\x45xecChat\x12\x0c.gnetcli.CMD\x1a\x12.gnetcli.CMDResult\"\x00(\x01\x30\x01\x12R\n\tAddDevice\x12\x0f.gnetcli.Device\x1a\x15.gnetcli.DeviceResult\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/add_device:\x01*\x12W\n\x0b\x45xecNetconf\x12\x13.gnetcli.CMDNetconf\x1a\x12.gnetcli.CMDResult\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/v1/exec_netconf:\x01*\x12@\n\x0f\x45xecNetconfChat\x12\x13.gnetcli.CMDNetconf\x1a\x12.gnetcli.CMDResult\"\x00(\x01\x30\x01\x12\\\n\x08\x44ownload\x12\x1c.gnetcli.FileDownloadRequest\x1a\x14.gnetcli.FilesResult\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/api/v1/downloads:\x01*\x12W\n\x06Upload\x12\x1a.gnetcli.FileUploadRequest\x1a\x16.google.protobuf.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/api/v1/upload:\x01*B7Z5github.com/annetutil/gnetcli/pkg/server/proto;gnetclib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'server_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z5github.com/annetutil/gnetcli/pkg/server/proto;gnetcli'
  _globals['_GNETCLI'].methods_by_name['SetupHostParams']._options = None
  _globals['_GNETCLI'].methods_by_name['SetupHostParams']._serialized_options = b'\202\323\344\223\002\036\"\031/api/v1/setup_host_params:\001*'
  _globals['_GNETCLI'].methods_by_name['Exec']._options = None
  _globals['_GNETCLI'].methods_by_name['Exec']._serialized_options = b'\202\323\344\223\002\021\"\014/api/v1/exec:\001*'
  _globals['_GNETCLI'].methods_by_name['AddDevice']._options = None
  _globals['_GNETCLI'].methods_by_name['AddDevice']._serialized_options = b'\202\323\344\223\002\027\"\022/api/v1/add_device:\001*'
  _globals['_GNETCLI'].methods_by_name['ExecNetconf']._options = None
  _globals['_GNETCLI'].methods_by_name['ExecNetconf']._serialized_options = b'\202\323\344\223\002\031\"\024/api/v1/exec_netconf:\001*'
  _globals['_GNETCLI'].methods_by_name['Download']._options = None
  _globals['_GNETCLI'].methods_by_name['Download']._serialized_options = b'\202\323\344\223\002\026\"\021/api/v1/downloads:\001*'
  _globals['_GNETCLI'].methods_by_name['Upload']._options = None
  _globals['_GNETCLI'].methods_by_name['Upload']._serialized_options = b'\202\323\344\223\002\023\"\016/api/v1/upload:\001*'
  _globals['_TRACEOPERATION']._serialized_start=1311
  _globals['_TRACEOPERATION']._serialized_end=1413
  _globals['_DEVICERESULTSTATUS']._serialized_start=1415
  _globals['_DEVICERESULTSTATUS']._serialized_end=1487
  _globals['_FILESTATUS']._serialized_start=1489
  _globals['_FILESTATUS']._serialized_end=1614
  _globals['_QA']._serialized_start=84
  _globals['_QA']._serialized_end=122
  _globals['_CREDENTIALS']._serialized_start=124
  _globals['_CREDENTIALS']._serialized_end=170
  _globals['_CMD']._serialized_start=173
  _globals['_CMD']._serialized_end=353
  _globals['_DEVICE']._serialized_start=355
  _globals['_DEVICE']._serialized_end=456
  _globals['_CMDNETCONF']._serialized_start=458
  _globals['_CMDNETCONF']._serialized_end=554
  _globals['_CMDTRACEITEM']._serialized_start=556
  _globals['_CMDTRACEITEM']._serialized_end=628
  _globals['_HOSTPARAMS']._serialized_start=630
  _globals['_HOSTPARAMS']._serialized_end=741
  _globals['_CMDRESULT']._serialized_start=744
  _globals['_CMDRESULT']._serialized_end=873
  _globals['_DEVICERESULT']._serialized_start=875
  _globals['_DEVICERESULT']._serialized_end=946
  _globals['_FILEDOWNLOADREQUEST']._serialized_start=948
  _globals['_FILEDOWNLOADREQUEST']._serialized_end=1056
  _globals['_FILEDATA']._serialized_start=1058
  _globals['_FILEDATA']._serialized_end=1133
  _globals['_FILEUPLOADREQUEST']._serialized_start=1135
  _globals['_FILEUPLOADREQUEST']._serialized_end=1260
  _globals['_FILESRESULT']._serialized_start=1262
  _globals['_FILESRESULT']._serialized_end=1309
  _globals['_GNETCLI']._serialized_start=1617
  _globals['_GNETCLI']._serialized_end=2269
# @@protoc_insertion_point(module_scope)
